.. atx documentation master file, created by
   sphinx-quickstart on Mon Mar  7 13:34:33 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ATX's documentation!
===================================
Release you from the boring testing work.

Documentation
-------------

.. toctree::
    :maxdepth: 3

    usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

